
TODO_54_68_18_12: Support defaults for config-only delegator

NOTE: This is already implemented, but:
*   TODO: Declare (dynamically via `eval`) local variables named according to the config to be able to reference it in templates.
*   TODO: Update docs accordingly.

It should be possible to configure defaults statically per container per prop,
for example (considering it is for `@/data/ConfigOnlyLoader.data.yaml`):

```yaml
envelope_payload:
    fill_control_list:
        -   envelope_class: ConfigOnlyClass
            props_to_values_list:
                -   severity_level: ERROR
```

Each list item under `fill_control_list` specifies defaults assigned statically per `envelope_container`.

